PD_ConfigEnableXpu

Struct PD_ConfigEnableXpu 

pub struct PD_ConfigEnableXpu;
\brief Turn on XPU.

\param[in] pd_onfig config \param l3_workspace_size The size of the video memory allocated by the l3 cache, the maximum is 16M. \param locked Whether the allocated L3 cache can be locked. If false, it means that the L3 cache is not locked, and the allocated L3 cache can be shared by multiple models, and multiple models sharing the L3 cache will be executed sequentially on the card. \param autotune Whether to autotune the conv operator in the model. If true, when the conv operator of a certain dimension is executed for the first time, it will automatically search for a better algorithm to improve the performance of subsequent conv operators of the same dimension. \param autotune_file Specify the path of the autotune file. If autotune_file is specified, the algorithm specified in the file will be used and autotune will not be performed again. \param precision Calculation accuracy of multi_encoder \param adaptive_seqlen Is the input of multi_encoder variable length